@@ -11,7 +11,17 @@ def raise_errors_on_failure(resp, body=None):
     elif resp.status_code == 401:
         raise errors.AuthenticationError("Unauthorized")
     elif resp.status_code == 403:
-        raise errors.AuthenticationError("Forbidden")
+        if (
+            "x-evervault-error-code" in resp.headers
+            and resp.headers["x-evervault-error-code"] == "forbidden-ip-error"
+        ):
+            raise errors.ForbiddenIPError("IP is not present in Cage whitelist")
+        else:
+            raise errors.AuthenticationError("Forbidden")
+    elif resp.status_code == 408:
+        raise errors.TimeoutError("Request timed out")
+    elif resp.status_code == 422:
+        raise errors.DecryptionError("Unable to decrypt data")
     elif resp.status_code == 500:
         raise errors.ServerError("Server Error")
     elif resp.status_code == 502:
@@ -23,7 +33,7 @@ def raise_errors_on_failure(resp, body=None):
 
 
 def __message_for_unexpected_error_without_type(error_details):
-    if error_details != None:
+    if error_details is not None:
         message = error_details["message"]
         status_code = error_details["statusCode"]
         return (
