@@ -21,6 +21,14 @@ class AuthenticationError(EvervaultError):
     pass
 
 
+class TimeoutError(EvervaultError):
+    pass
+
+
+class DecryptionError(EvervaultError):
+    pass
+
+
 class ServerError(EvervaultError):
     pass
 
@@ -48,11 +56,22 @@ class InvalidPublicKeyError(EvervaultError):
 class UnexpectedError(EvervaultError):
     pass
 
+
 class MissingTeamEcdhKey(EvervaultError):
     pass
 
+
 class UnknownEncryptType(EvervaultError):
     pass
 
+
 class CertDownloadError(EvervaultError):
-    pass
\ No newline at end of file
+    pass
+
+
+class ForbiddenIPError(EvervaultError):
+    pass
+
+
+class UnsupportedCurveError(EvervaultError):
+    pass
